@@ -20,12 +20,6 @@ prTblNo <- function (caption) {
       return(caption)
   }
 
-  # Count which table it currently is
-  if (is.numeric(tc))
-    tc <- tc + 1
-  else
-    tc <- 1
-  options(table_counter = tc)
   table_template <- getOption("table_counter_str", "Table %s: ")
   out <- sprintf(table_template,
                  ifelse(getOption("table_counter_roman", FALSE),
@@ -159,7 +153,13 @@ prGetStyle <- function(...){
 #' @keywords internal
 #' @family hidden helper functions for \code{\link{htmlTable}}
 prAddSemicolon2StrEnd <- function(my_str){
-  my_str <- str_trim(my_str)
+  if (!is.null(names(my_str))){
+    tmp <- str_trim(my_str)
+    names(tmp) <- names(my_str)
+    my_str <- tmp
+  }else{
+    my_str <- str_trim(my_str)
+  }
   my_str_n <- sapply(my_str, nchar, USE.NAMES = FALSE)
   if (any(my_str_n == 0))
     my_str <- my_str[my_str_n > 0]
@@ -538,7 +538,9 @@ prAddCells <- function(rowcells, cellcode, align, style, cgroup_spacer_cells, ha
               cellcode)
 
     # Add empty cell if not last column
-    if (nr != length(rowcells) && cgroup_spacer_cells[nr] > 0){
+    if (nr != length(rowcells) &&
+          nr <= length(cgroup_spacer_cells) &&
+          cgroup_spacer_cells[nr] > 0){
       spanner_style <- style
       if (!missing(col.columns)){
         if (col.columns[nr] == col.columns[nr + 1]){
